import {Component, OnInit} from '@angular/core';
import {FormArray, FormBuilder, FormControl, FormGroup, FormGroupDirective, NgForm, Validators} from '@angular/forms';
import {ErrorStateMatcher, MatSnackBar} from '@angular/material';
import {TermAdminService} from '../../services/termin-admin-service.service';
import {NewTerms} from '../../models/NewTerms';

@Component({
  selector: 'app-add-terms',
  templateUrl: './add-terms.component.html',
  styleUrls: ['./add-terms.component.css']
})

export class AddTermsComponent implements OnInit {

  form: FormGroup;

  yearItems = [ 2019, 2020, 2021, 2022, 2023];
  months = [
    {key: 1, value: 'Styczeń'},
    {key: 2, value: 'Luty'},
    {key: 3, value: 'Marzec'},
    {key: 4, value: 'Kwieceń'},
    {key: 5, value: 'Maj'},
    {key: 6, value: 'Czerwiec'},
    {key: 7, value: 'Lipiec'},
    {key: 8, value: 'Sierpień'},
    {key: 9, value: 'Wrzesień'},
    {key: 10, value: 'Październik'},
    {key: 11, value: 'Listopad'},
    {key: 12, value: 'Grudzień'}
  ];

  constructor(private formBuilder: FormBuilder, private termAdminService: TermAdminService, public snackBar: MatSnackBar) {
    const controls = this.months.map(c => new FormControl(false));

    this.form = this.formBuilder.group({
      year: new FormControl(null, Validators.required),
      orders: new FormArray(controls)
    });
  }

  ngOnInit() {
    // this.createForm();
  }

  submit() {
    const selectedOrderIds = this.form.value.orders
      .map((v, i) => v ? this.months[i].key : null)
      .filter(v => v !== null);

    const newTerms = new NewTerms();
    newTerms.year = this.form.controls.year.value;
    newTerms.months = selectedOrderIds;
    this.termAdminService.createTerm(newTerms).subscribe(
      x => {
        this.openSnackBar('Dodano terminy !');
      },
      error => this.openSnackBar('Coś poszło nie tak, być może istnieją już terminy w bazie danych.\nJeśli tak to zostały dodane tylko te, których brak.\nDla pewności sprawdź czy dane się zapisały'));
  }

  openSnackBar(message: string) {
    this.snackBar.open(message, null, {
      duration: 5000,
    });
  }

  do() {
    console.log(this.form);
  }
}

