import {Component, Inject} from '@angular/core';
import {MAT_DIALOG_DATA, MatDialogRef, MatSnackBar} from '@angular/material';
import {FormControl, FormGroup, Validators} from '@angular/forms';
import {Query} from '../../../models/Query';
import {QueryService} from '../../../services/query.service';
import {MomentDateAdapter} from '@angular/material-moment-adapter';
import {DateAdapter, MAT_DATE_FORMATS, MAT_DATE_LOCALE} from '@angular/material/core';

import * as _moment from 'moment';
// tslint:disable-next-line:no-duplicate-imports
// @ts-ignore
import {default as _rollupMoment} from 'moment';

const moment = _rollupMoment || _moment;

export const MY_FORMATS = {
  parse: {
    dateInput: 'LL',
  },
  display: {
    dateInput: 'LL',
    monthYearLabel: 'MMM YYYY',
    dateA11yLabel: 'LL',
    monthYearA11yLabel: 'MMMM YYYY',
  },
};

@Component({
  selector: 'app-create-query',
  templateUrl: './create-query.component.html',
  styleUrls: ['./create-query.component.css'],
  providers: [
    // `MomentDateAdapter` can be automatically provided by importing `MomentDateModule` in your
    // application's root module. We provide it at the component level here, due to limitations of
    // our example generation script.
// @ts-ignore
    {provide: DateAdapter, useClass: MomentDateAdapter, deps: [MAT_DATE_LOCALE]},

    {provide: MAT_DATE_FORMATS, useValue: MY_FORMATS},
  ],
})
export class CreateQueryComponent {

  test: string;
  form: FormGroup;

  newQuery = new Query();

  constructor(
    public dialogRef: MatDialogRef<CreateQueryComponent>, private queryService: QueryService, public snackBar: MatSnackBar) {

    this.form = new FormGroup({
      startdate: new FormControl('', [Validators.required]),
      enddate: new FormControl('', [Validators.required]),
      location: new FormControl(null, [Validators.required]),
      description: new FormControl('', [Validators.required]),
      contactperson: new FormControl(null, [Validators.required]),
      contactno: new FormControl(null, [Validators.required]),
      email: new FormControl(null, [Validators.required, Validators.email])
    });
  }

  onAbort(): void {
    this.dialogRef.close();
  }

  async onSubmit() {
    this.newQuery.startdate = this.form.controls.startdate.value;
    this.newQuery.enddate = this.form.controls.enddate.value;
    this.newQuery.location = this.form.controls.location.value;
    this.newQuery.description = this.form.controls.description.value;
    this.newQuery.contactperson = this.form.controls.contactperson.value;
    this.newQuery.contactno = this.form.controls.contactno.value;
    this.newQuery.email = this.form.controls.email.value;

    console.log('wysylam ', this.newQuery);
    await this.queryService.createQuery(this.newQuery).subscribe(
      x => {
        this.openSnackBar('Zapisano zmiany !');
        this.onAbort();
      },
      error => this.openSnackBar('Coś poszło nie tak.. Spróbuj ponownie'));
  }

  openSnackBar(message: string) {
    this.snackBar.open(message, null, {
      duration: 2500,
    });
  }
}
