import {Component, Inject, OnInit} from '@angular/core';
import {MAT_DIALOG_DATA, MatDialogRef, MatSnackBar} from '@angular/material';
import {Term} from '../../../models/Term';
import {FormControl, FormGroup, Validator, Validators} from '@angular/forms';
import {TermAdminService} from '../../../services/termin-admin-service.service';
import {TermListAdminComponent} from '../../term-list-admin/term-list-admin.component';

@Component({
  selector: 'app-edit-term-admin',
  templateUrl: './edit-term-admin.component.html',
  styleUrls: ['./edit-term-admin.component.css']
})
export class EditTermAdminComponent implements OnInit {

  form: FormGroup;
  statuses = ['wolny', 'zarezerwowany'];

  constructor(private dialogRef: MatDialogRef<EditTermAdminComponent>,
              @Inject(MAT_DIALOG_DATA) public data: Term, private termAdminService: TermAdminService, public snackBar: MatSnackBar) {
  }

  ngOnInit() {
    this.form = new FormGroup({
      date: new FormControl(this.data.date, Validators.required),
      status: new FormControl(this.data.status, Validators.required),
      contractno: new FormControl(this.data.contractno, Validators.required)
    });
  }

  onAbort() {
    this.dialogRef.close();
  }

  onSubmit() {
    const term = new Term();
    term.date = this.form.controls.date.value;
    term.status = this.form.controls.status.value;
    term.contractno = this.form.controls.contractno.value;
    console.log(term);
    this.termAdminService.updateTerm(term).subscribe(
      x => {
        this.openSnackBar('Zapisano zmiany !');
        this.onAbort();
      },
      error => this.openSnackBar('Coś poszło nie tak.. Spróbuj ponownie'));
  }

  openSnackBar(message: string) {
    this.snackBar.open(message, null, {
      duration: 2500,
    });
  }

}
