import {Component, OnInit} from '@angular/core';
import {FormControl, FormGroup, Validators} from '@angular/forms';
import {Month} from '../../models/Month';
import {Observable} from 'rxjs';
import {Term} from '../../models/Term';
import {TermService} from '../../services/term.service';
import {MatDialog, MatSnackBar} from '@angular/material';
import {DataSources} from '../environments/DataSources';
import {TermAdminService} from '../../services/termin-admin-service.service';
import {EditTermAdminComponent} from '../dialogs/edit-term-admin/edit-term-admin.component';

@Component({
  selector: 'app-term-list-admin',
  templateUrl: './term-list-admin.component.html',
  styleUrls: ['./term-list-admin.component.css']
})
export class TermListAdminComponent implements OnInit {

  form: FormGroup;
  yearsList = [];
  monthsList: Month[];
  searchedProperty = false;

  allTerms$: Observable<Array<Term>>;

  constructor(private termService: TermService, private termAdminService: TermAdminService, public dialog: MatDialog, public snackBar: MatSnackBar) {
    this.yearsList = DataSources.yearsList;
    this.monthsList = DataSources.monthsList;
  }

  ngOnInit() {
    this.form = new FormGroup({
      year: new FormControl(null, Validators.required),
      month: new FormControl(null, Validators.required)
    });

    this.allTerms$ = this.termService.terms$;
    this.termService.termsObs.next(null);
  }

  async search() {
    await this.termService.getTerms(this.form.controls.year.value, this.form.controls.month.value);
    this.searchedProperty = true;


  }

  editTerm(event: Term) {
    this.openDialog(event);
  }

  async deleteTerm(event: Term) {
    event.date = event.date;
    event.status = 'wolny';
    event.contractno = '';
    await this.termAdminService.deleteTerm(event).subscribe(
      x => {
        this.openSnackBar('Zwolniono termin !');
      },
      error => {
        this.openSnackBar('Coś poszło nie tak.. Spróbuj ponownie');
      });
    this.termService.getTerms(this.form.controls.year.value, this.form.controls.month.value);
  }

  openDialog(term: Term): void {
    const dialogRef = this.dialog.open(EditTermAdminComponent, {
      width: '65%',
      data: term
    });

    dialogRef.afterClosed().subscribe(result => {
      this.termService.getTerms(this.form.controls.year.value, this.form.controls.month.value);
    });
  }

  openSnackBar(message: string) {
    this.snackBar.open(message, null, {
      duration: 2500,
    });
  }

}
