import {Component, OnInit} from '@angular/core';
import {FormControl, FormGroup, Validators} from '@angular/forms';
import {Month} from '../../models/Month';
import {DataSources} from '../environments/DataSources';
import {TermService} from '../../services/term.service';
import {Term} from '../../models/Term';
import {Observable} from 'rxjs';
import {MatDialog} from '@angular/material';
import {CreateQueryComponent} from '../dialogs/create-query/create-query.component';

@Component({
  selector: 'app-term-list',
  templateUrl: './term-list.component.html',
  styleUrls: ['./term-list.component.css']
})
export class TermListComponent implements OnInit {
  form: FormGroup;
  yearsList = [];
  monthsList: Month[];
  searchedProperty = false;

  displayedColumns: string[] = ['weekDay', 'date', 'availability'];

  allTerms$: Observable<Array<Term>>;

  constructor(private termService: TermService, private dialog: MatDialog) {
    this.yearsList = DataSources.yearsList;
    this.monthsList = DataSources.monthsList;
  }

  ngOnInit() {
    this.form = new FormGroup({
      year: new FormControl(null, Validators.required),
      month: new FormControl(null, Validators.required)
    });

    this.allTerms$ = this.termService.terms$;
  }

  async search() {
    console.log(this.form.value);
    await this.termService.getTerms(this.form.controls.year.value, this.form.controls.month.value);
    this.searchedProperty = true;
  }

  openDialog(): void {
    const dialogRef = this.dialog.open(CreateQueryComponent, {
      width: '65%',
    });
  }

}

