import { Injectable } from '@angular/core';
import {HttpClient, HttpHeaders} from '@angular/common/http';
import {Query} from '../models/Query';
import {environment} from '../../environments/environment';
import {BehaviorSubject} from 'rxjs';
import {Term} from '../models/Term';

const httpOptions = {
  headers: new HttpHeaders({ 'Content-Type': 'application/json' })
};

@Injectable({
  providedIn: 'root'
})
export class QueryService {

  private queryListObs = new BehaviorSubject<Array<Query>>([]);
  queryList$ = this.queryListObs.asObservable();


  constructor(private httpClient: HttpClient) { }

  createQuery(query: Query) {
    console.log('post', query);
    return this.httpClient.post(environment.API_BACK + 'query', query, httpOptions);
  }


  getQueryList() {
    return this.httpClient.get<Array<Query>>(environment.API_BACK + 'query')
      .subscribe(x => {
          console.log(x);
          this.queryListObs.next(x);
        },
        err => {
          console.log(err);
        });
  }

  updateQuery(query: Query) {
    const headers = new HttpHeaders();
    headers.set('Content-Type', 'application/json; charset=utf-8');
    headers.set('Access-Control-Allow-Origin', '*');
    headers.set('Access-Control-Allow-Methods', 'GET, POST, OPTIONS, PUT, PATCH, DELETE');

  // @ts-ignore
    return this.httpClient.put<Query>(environment.API_BACK + 'query', query, headers);
  }
}
